

--[[-
		Micro mission:	The meeting

		Pickup your friend and drive him to the blip
--]]


-- 'Settings'
mission_name = "The Meeting"
mission_reward = 200000
friend_model = 0x58A1E271 -- LJ
model_type = 2
meeting_point = { x = -526.43951416016, y = 1483.302734375}
arrival_point = { x = -264.27114868164, y = 1498.3988037109}
friend_name = "CJ"

--vars
player_ped = nil
player_idx = nil
friend_ped = nil
friend_blip = nil
arrival_blip = nil
friend_ped_ref = nil
player_group = nil
state = 0
honk_msg_shown = false
getcar_msg_shown = false
arrival_blip_made = false

-- helper functions

function get_player()
	local bla = GET_PLAYER_ID().i
 	local pi = CONVERT_INT_TO_PLAYERINDEX(bla)
	return pi.p;
end

function get_player_ped()
 	local ped = {}
 	GET_PLAYER_CHAR(player_idx, ped)
 	return ped.p
end

function get_ground_z(x, y, z)
 	local tmpz = 0
 	local zref = {}
	SETTIMERA(0)
	while (tmpz == 0 and TIMERA().u < 5000) do
 		GET_GROUND_Z_FOR_3D_COORD(x, y, z, zref)
 		tmpz = zref.f
 		Wait(0)
 	end
	if (tmpz == 0) then
		Log("cannot get z")
		return 0.1
	end
	return tmpz
end

function make_guard(ped)
	CLEAR_CHAR_TASKS_IMMEDIATELY(ped)
	SET_GROUP_MEMBER(player_group, ped)
	SET_GROUP_SEPARATION_RANGE(player_group, 9999.9)
	SET_CHAR_NEVER_LEAVES_GROUP(ped, 1)
	SET_LOAD_COLLISION_FOR_CHAR_FLAG(ped, 1)
	SET_CHAR_WILL_MOVE_WHEN_INJURED(ped, 1)
	SET_PED_DIES_WHEN_INJURED(ped, 1)

	local charDec = {}
	local combatDec = {}
	LOAD_CHAR_DECISION_MAKER(2, charDec)
	LOAD_COMBAT_DECISION_MAKER(9, combatDec)
	SET_CHAR_DECISION_MAKER(ped, charDec.u)
	SET_COMBAT_DECISION_MAKER(ped, combatDec.u)

end

function room_in_car(car)
	if( IS_CAR_PASSENGER_SEAT_FREE(car, 0)
			or IS_CAR_PASSENGER_SEAT_FREE(car, 1)
			or IS_CAR_PASSENGER_SEAT_FREE(car, 2) ) then
		return true
	end
	return false
end

function get_into_car_as_passenger(ped, car)
	for i=0,2 do
		if (IS_CAR_PASSENGER_SEAT_FREE(car, i).b) then
			TASK_ENTER_CAR_AS_PASSENGER(ped, car, -2, i)
			return true
		end
	end
	return false
end

 -- mission functions

function start_mission()
	-- Create friend with blip
	local fb, pg = {}, {}
	friend_ped_ref = {}
	SET_WANTED_MULTIPLIER(0.0000001)
	meeting_point.z = get_ground_z(meeting_point.x, meeting_point.y,1000.1)
	arrival_point.z = get_ground_z(arrival_point.x, arrival_point.y,1000.1)
	player_idx = get_player()
 	player_ped = get_player_ped()
	GET_PLAYER_GROUP(player_idx, pg)
	player_group = pg.p

	REQUEST_MODEL(friend_model);
	LOAD_ALL_OBJECTS_NOW()
	while (not HAS_MODEL_LOADED(friend_model).b) do
		Wait(1)
	end
	CREATE_CHAR(model_type, friend_model, meeting_point.x, meeting_point.y , meeting_point.z, friend_ped_ref, 1)
	friend_ped = friend_ped_ref.p

	MARK_MODEL_AS_NO_LONGER_NEEDED(friend_model)

	ADD_BLIP_FOR_CHAR(friend_ped, fb)
	friend_blip = fb.p
	SET_BLIP_AS_FRIENDLY(friend_blip, 1)
	SET_ROUTE(friend_blip, 1)
	CHANGE_BLIP_NAME_FROM_ASCII(friend_bip, friend_name)
end


function mission_cleanup()
	if (DOES_BLIP_EXIST(friend_blip).b) then
		SET_ROUTE(friend_blip, 0)
		REMOVE_BLIP(friend_blip)
	end
	if (DOES_BLIP_EXIST(arrival_blip).b) then
		SET_ROUTE(arrival_blip, 0)
		REMOVE_BLIP(arrival_blip)
	end
	if (DOES_CHAR_EXIST(friend_ped).b) then
		if(not IS_CHAR_INJURED(friend_ped).b) then
			SET_CHAR_DECISION_MAKER_TO_DEFAULT(friend_ped)
			if (IS_GROUP_MEMBER(friend_ped, player_group).b) then
				SET_CHAR_NEVER_LEAVES_GROUP(friend_ped, 0)
				REMOVE_CHAR_FROM_GROUP(friend_ped)
			end
		end
		TASK_WANDER_STANDARD(friend_ped)
		REMOVE_CHAR_ELEGANTLY(friend_ped_ref)
		MARK_CHAR_AS_NO_LONGER_NEEDED(friend_ped_ref)
	end
end

function mission_success()
 	local done = false
 	Log("mission success")
 	SETTIMERA(0)

 	-- keep trying for 20 secs
 	while ((not done) and (TIMERA().u < 20000)) do
 		if (CAN_START_MISSION_PASSED_TUNE().b) then
 			TRIGGER_MISSION_COMPLETE_AUDIO(53)
			ADD_SCORE(player_idx, mission_reward)
 			done = true
 		end
 		Wait(50)
 	end
 	if (not done) then
 		Log("Cannot pass mission")
 	end
end

function tick()
	local veh_ref, fb = {}, {}

	-- friend not yet met
	if (state == 0) then
		if (LOCATE_CHAR_ANY_MEANS_CHAR_2D(player_ped,friend_ped, 18.1, 18.1,0).b) then
			-- friend is close range
			if (HAS_CHAR_SPOTTED_CHAR(friend_ped, player_ped).b or IS_PLAYER_PRESSING_HORN(player_idx).b) then
				-- got his attention
				make_guard(friend_ped)
				if (DOES_BLIP_EXIST(friend_blip).b) then
					SET_ROUTE(friend_blip, 0)
					REMOVE_BLIP(friend_blip)
				end
				state = 1
				Log("0 -> 1")
			else
				if (IS_CHAR_SITTING_IN_ANY_CAR(player_ped).b and not honk_msg_shown) then
					PRINT_STRING_WITH_LITERAL_STRING_NOW("STRING", "honk horn", 3000, 1)
					honk_msg_shown = true
				end
			end
		end
	end
	-- friend met but not yet both in car
	if (state == 1) then
		if (IS_CHAR_SITTING_IN_ANY_CAR(player_ped).b) then
			-- get friend in car
			GET_CAR_CHAR_IS_USING(player_ped, veh_ref)
			if (IS_CHAR_IN_CAR(friend_ped, veh_ref.p).b) then
				if not arrival_blip_made then
					local abr = {}
					--hhmm ADD_BLIP_FOR_CONTACT adds a cool yellow marker but it's HUGE :(
					--this should add the marker too like in roman6 (jamaican heat) but it doesn't....
					ADD_BLIP_FOR_COORD(arrival_point.x, arrival_point.y, arrival_point.z, abr)
					arrival_blip = abr.p
					arrival_blip_made = true
				end
				CHANGE_BLIP_DISPLAY(arrival_blip, 4)
				Log("1 -> 2")
				state = 2
			--[[else
				if (LOCATE_CHAR_ANY_MEANS_CHAR_2D(player_ped, friend_ped, 15.1, 15.1, 0).b) then
					-- friend close to car, get in
					get_into_car_as_passenger(friend_ped, veh_ref.p)
					if (DOES_BLIP_EXIST(friend_blip).b) then
						SET_ROUTE(friend_blip, 0)
						REMOVE_BLIP(friend_blip)
					end
				elseif (LOCATE_CHAR_ANY_MEANS_CHAR_2D(player_ped, friend_ped, 30.1, 30.1, 0).b) then
					-- he's to far
					CLEAR_CHAR_TASKS(friend_ped)
					if (not DOES_BLIP_EXIST(friend_blip).b) then
						--restore blip
						ADD_BLIP_FOR_CHAR(friend_ped, fb)
						friend_blip = fb.p
						SET_ROUTE(friend_blip, 1)
					end
				end
			--]]
			end
		else
			-- get car
			if (not getcar_msg_shown) then
				PRINT_STRING_WITH_LITERAL_STRING_NOW("STRING", "get a car", 3000, 1)
				getcar_msg_shown = true
			end
		end
	end
	-- player and friend in car
	if(state == 2) then
		if (IS_CHAR_SITTING_IN_ANY_CAR(player_ped).b) then
			GET_CAR_CHAR_IS_USING(player_ped, veh_ref)
			if (not IS_CHAR_IN_CAR(friend_ped, veh_ref.p)) then
				-- friend not in car
				if (DOES_BLIP_EXIST(arrival_blip).b) then
					CHANGE_BLIP_DISPLAY(arrival_blip, 0)
				end
				PRINT_STRING_WITH_LITERAL_STRING_NOW("STRING", "pickup your friend", 3000, 1)
				state = 1
				Log("2 -> 1 a")
				return
			else
				if (LOCATE_CHAR_ANY_MEANS_3D(player_ped, arrival_point.x,
						arrival_point.y, arrival_point.z, 5.1, 5.1, 2.1, 0).b and
						LOCATE_CHAR_ANY_MEANS_3D(friend_ped, arrival_point.x,
						arrival_point.y, arrival_point.z, 5.1, 5.1, 2.1, 0).b) then
					--stop the car to let LJ out
					if (IS_CHAR_SITTING_IN_ANY_CAR(player_ped).b) then
						local veh_ref = {}
						GET_CAR_CHAR_IS_USING(player_ped, veh_ref)
						SET_PLAYER_CONTROL(player_idx, 0)
						SET_CAR_FORWARD_SPEED(veh_ref.p, 0)
						SET_CHAR_DECISION_MAKER_TO_DEFAULT(friend_ped)
						if (IS_GROUP_MEMBER(friend_ped, player_group).b) then
							SET_CHAR_NEVER_LEAVES_GROUP(friend_ped, 0)
							REMOVE_CHAR_FROM_GROUP(friend_ped)
						end
						TASK_WANDER_STANDARD(friend_ped)
						REMOVE_CHAR_ELEGANTLY(friend_ped_ref)
						MARK_CHAR_AS_NO_LONGER_NEEDED(friend_ped_ref)

						Wait(2000)
						SET_PLAYER_CONTROL(player_idx, 1)
					end
					mission_success()
					return true
				end
			end
		else
			-- player got out
			state = 1
			Log("2 -> 1 b")
			if (DOES_BLIP_EXIST(arrival_blip).b) then
				CHANGE_BLIP_DISPLAY(arrival_blip, 0)
			end
			PRINT_STRING_WITH_LITERAL_STRING_NOW("STRING", "get a car", 3000, 1)
			return
		end
	end

	return false
end

function main()
 	Log("Starting mission: " .. mission_name)
 	PRINT_STRING_WITH_LITERAL_STRING_NOW("STRING", mission_name, 3000, 1)
 	start_mission()
	Wait(100)
 	while (IsThreadAlive()) do
 		if (GetKey(VK_F10)) then
			mission_cleanup()
 			return
 		end
		if tick() then
			mission_cleanup()
			return
		end
 		Wait(100)
 	end
end

main()

