#include "GompieThread.h"
#include <windows.h>

#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <stdlib.h>
#include "Scripting.h"
#include "ScriptingEnums.h"
#include "ScriptingTypes.h"
#include <iostream>
#include <fstream>
void register_lua_ops(lua_State *L);
int lua_invoke(lua_State *L);

struct native_info{
	u32 hash;
	int argc;
	bool hasret;
	const char *name;
};

extern struct native_info lua_native_exports[1989];
#define N_NATIVE_EXPORTS 1988


GompieThread::GompieThread(){
	SetName("GompieThread");
	//log.open("lualog.txt",std::ios::out|std::ios::trunc);
	log.open("lualog.txt");
	log << "Starting gompiethread" << std::endl;
	//log.open("lualog.txt", std::ios::out|std::ios::app|std::ios::trunc);
	//log.setf(std::ios_base::unitbuf);
}

GompieThread::~GompieThread(){
	log.close();
}

void GompieThread::RunScript(){
	while(IsThreadAlive()){
		if ((GetAsyncKeyState(VK_F4) & 1) != 0){
			
				//scriptRunning = true;
				ExecuteScript("lua/main.lua", false);
				//scriptRunning = false;
        }
		//
		Wait(100);
	}
}

void GompieThread::RegisterNatives(lua_State *L){
	int i = 0;
	for(;i<N_NATIVE_EXPORTS;i++){
		lua_pushinteger(L, lua_native_exports[i].hash);
		lua_pushinteger(L, lua_native_exports[i].argc);
		lua_pushboolean(L, lua_native_exports[i].hasret);
		lua_pushstring(L, lua_native_exports[i].name);
		lua_pushcclosure(L, lua_invoke, 4);
		lua_setglobal(L, lua_native_exports[i].name);
	}
}

void GompieThread::RegisterOps(lua_State *L){
	register_lua_ops(L);
}

void GompieThread::LuaError(lua_State *L, const char *when, const char *msg){
	log << "ERROR: " << when << ":" << msg << std::endl;
	ShowError("%s", lua_tostring(L, -1));

}
static int traceback (lua_State *L) {
  lua_getfield(L, LUA_GLOBALSINDEX, "debug");
  if (!lua_istable(L, -1)) {
    lua_pop(L, 1);
    return 1;
  }
  lua_getfield(L, -1, "traceback");
  if (!lua_isfunction(L, -1)) {
    lua_pop(L, 2);
    return 1;
  }
  lua_pushvalue(L, 1);  /* pass error message */
  lua_pushinteger(L, 2);  /* skip this function and traceback */
  lua_call(L, 2, 1);  /* call debug.traceback */
  return 1;
}

void GompieThread::ExecuteScript(const char *filename, bool inThread){
	//if(!scriptRunning){
		log << "Running script" << std::endl;
		lua_State *L = lua_open();  
		luaL_openlibs(L);
		RegisterNatives(L);
		RegisterOps(L);
		if(luaL_loadfile(L, filename)){
			LuaError(L, "loading file", lua_tostring(L, -1));
		}else{
			int base = lua_gettop(L);
			lua_pushcfunction(L, traceback);
			lua_insert(L, base);

			if(lua_pcall(L,0,0,1)){
				LuaError(L, "running file", lua_tostring(L, -1));
			}
		}
		//scriptRunning = false;
		log << "done" << std::endl; 
		lua_close(L);
	//}
}

void GompieThread::ShowError(const char *fmt, ...){
	va_list arg_ptr;
	va_start(arg_ptr, fmt);
	char buffer[1024];
	vsnprintf_s(buffer, 1024, _TRUNCATE, fmt, arg_ptr);
	Scripting::PrintStringWithLiteralStringNow("STRING", buffer, 5000, 1);
	va_end(arg_ptr);
}





