#include <windows.h>
#include <math.h>
#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <stdlib.h>
#include "ScriptHookManager.h"
#include "Scripting.h"
#include "ScriptThread.h"
#include "ScriptingEnums.h"
#include "ScriptingTypes.h"
#include <lua.h>
#include <lauxlib.h>
#include <lualib.h> 
#include "GompieThread.h"
#include "gompie.h"

using namespace Scripting;
typedef void (_cdecl *NativeCall)(GameTypes::scrNativeCallContext *cxt);
extern GompieThread gompieThread;
extern struct key_info vklua_keys[N_KEYS];
static int trace = 0;

static void mk_lua_union(lua_State *L, u32 v, int idx){
	lua_pushstring(L, "u");
	lua_pushnumber(L,(double)v);
	lua_settable(L, idx);

	lua_pushstring(L, "i");
	lua_pushnumber(L,(double)*((int *)&v));
	lua_settable(L, idx);

	lua_pushstring(L, "f");
	lua_pushnumber(L,(double)*((f32 *)&v));
	lua_settable(L, idx);

	lua_pushstring(L, "p");
	lua_pushlightuserdata(L,(u32 *)v);
	lua_settable(L, idx);

	lua_pushstring(L, "b");
	lua_pushboolean(L,v!=0);
	lua_settable(L, idx);
}

u32 get_lua_tbldata(lua_State *L, int idx){
	u32 val;
	lua_pushstring(L, "p");
	lua_gettable(L, idx);
	if(lua_islightuserdata(L, idx)){
		val = (u32)lua_touserdata(L, 1);
		lua_pop(L, 1);
		return val;
	}
	lua_pop(L, 1);

	lua_pushstring(L, "u");
	lua_gettable(L, idx);
	if(lua_isnumber(L, idx)){
		val = (u32)lua_tonumber(L, 1);
		lua_pop(L, 1);
		return val;
	}
	lua_pop(L, 1);

	lua_pushstring(L, "f");
	lua_gettable(L, idx);
	if(lua_isnumber(L, idx)){
		f32 ft = (float)lua_tonumber(L, 1);
		val = *((u32 *)&ft);
		lua_pop(L, 1);
		return val;
	}
	lua_pop(L, 1);

	lua_pushstring(L, "i");
	lua_gettable(L, idx);
	if(lua_isnumber(L, idx)){
		int it = (int)lua_tonumber(L, 1);
		val = *((u32 *)&it);
		lua_pop(L, 1);
		return val;
	}
	lua_pop(L, 1);

	lua_pushstring(L, "b");
	lua_gettable(L, idx);
	if(lua_isboolean(L, idx)){
		val = (u32)lua_toboolean(L, 1);
		lua_pop(L, 1);
		return val;
	}
	lua_pop(L, 1);
	return 0;
}

int lua_invoke(lua_State *L){
	int i;
	NativeContext ctx;
	ptr fn;
	u32 hash = lua_tointeger(L, lua_upvalueindex(1));
	int argc = lua_tointeger(L, lua_upvalueindex(2));
	int hasret = lua_toboolean(L, lua_upvalueindex(3));
	const char *name = lua_tostring(L, lua_upvalueindex(4));
	u32 value, retval;
	struct {int lua_stk_idx;u32 data;} refstk[20];
	int refcnt = 0;

	if(trace)gompieThread.log << "TRACE: Invoking " << name << std::endl;
	//push args
	for(i=0;i<argc;i++){
		if(lua_isnumber(L, i+1)){
			double d = lua_tonumber(L, i+1);
			if(d-floor(d) == 0 && d <= 0xFFFFFFFF){
				if(d<0){
					int i = (int)d;
					value = *((u32 *)&(i));
				}else value = (u32)d;
			}else{
				float f = (float)d;
				value = *((u32 *)&(f));
			}
			//gompieThread.log << "push nmbr : " << value << " @ "<< i << std::endl;
		}else if(lua_islightuserdata(L,i+1)){
			value = (u32)lua_touserdata(L,i+1);
			//gompieThread.log << "push ptr : " << value << " @ "<< i << std::endl;
		}else if(lua_isstring(L,i+1)){
			value = (u32)lua_tostring(L,i+1);
			//gompieThread.log << "push str : " << value << " @ "<< i << std::endl;
		}else if(lua_istable(L, i+1)){
			refstk[refcnt].lua_stk_idx = i+1;
			refstk[refcnt].data = get_lua_tbldata(L, i+1);
			value = (u32)&refstk[refcnt++].data;
			//gompieThread.log << "push ref : " << value << " @ "<< i << std::endl;
		}else if(lua_isnoneornil(L, i+1)){
			value = 0;
			//gompieThread.log << "Warning: none or nil on stack... @ "<< i << std::endl;
		}
		ctx.Push<u32>(value);
	}	

	//gompieThread.log << "trace1" << std::endl;
	fn = Game::GetNativeAddressFromHash(hash);
	NativeCall call = (NativeCall)fn;
	call(&ctx);
	//gompieThread.log << "trace2" << std::endl;
	
	//restore refs
	for(i=0;i<refcnt;i++){
		mk_lua_union(L, refstk[i].data, refstk[i].lua_stk_idx);
	}
	//gompieThread.log << "trace3" << std::endl;
	
	if(hasret){
		retval = ctx.GetResult<u32>();
		//push new table (invalidates lua stack indexes)
		lua_newtable(L);
		mk_lua_union(L, retval, -3);
		//gompieThread.log << "trace4"<<std::endl;
		return 1;
	}else return 0;
}
static int luacb_wait(lua_State *L){
	int i = luaL_checkint(L, 1);
	gompieThread.LuaWait(i);
	return 0;
}

static int luacb_log(lua_State *L){
	const char *str = lua_tostring(L, 1);
	gompieThread.log << str << std::endl;
	//LogInfo(str);
	return 0;
}

static int luacb_dbg(lua_State *L){
	const char *str = lua_tostring(L, 1);
	gompieThread.log << str << std::endl;
	//LogInfo(str);
	Scripting::PrintStringWithLiteralStringNow("STRING", str, 3000, 1);
	return 0;
}
//if we would interpret this as a float already do noting
static int luacb_f(lua_State *L){
	double d = lua_tonumber(L, 1);
	if(d-floor(d) == 0 && d <= 0xFFFFFFFF){
		float f = (float)d;
		lua_pushnumber(L, (double)(*((u32 *)&f)));
	}else{
		lua_pushnumber(L, d);
	}
	return 1;
}

static int luacb_is_thread_alive(lua_State *L){
	int ia = gompieThread.GetThreadIsAlive();
	lua_pushboolean(L, ia);
	return 1;
}

static int luacb_get_key(lua_State *L){
	int i = lua_tointeger(L,1);
	lua_pushboolean(L, GetAsyncKeyState(i) & 1);
	return 1;
}

static int luacb_terminate_this_script(lua_State *L){
	gompieThread.TerminateScript();
	return 0;
}



static int luacb_trace(lua_State *L){
	trace = lua_toboolean(L,1);
	return 0;
}

static void register_keys(lua_State *L){
	int i;
	for(i=0;i<N_KEYS;i++){
		lua_pushinteger(L, vklua_keys[i].val);
		lua_setglobal(L, vklua_keys[i].name);
	}
}

void register_lua_ops(lua_State *L){
	lua_register(L, "f", luacb_f);
	lua_register(L, "Log", luacb_log);
	lua_register(L, "Dbg", luacb_dbg);
	lua_register(L, "Wait", luacb_wait);
	lua_register(L, "IsThreadAlive", luacb_is_thread_alive);
	lua_register(L, "GetKey", luacb_get_key);
	lua_register(L, "Trace", luacb_trace);
	lua_register(L, "TerminateThisScript", luacb_terminate_this_script);
	register_keys(L);
}

